searchData={"items":[{"type":"module","title":"Idiom","doc":"","ref":"Idiom.html"},{"type":"function","title":"Idiom.child_spec/1","doc":"","ref":"Idiom.html#child_spec/1"},{"type":"function","title":"Idiom.t/2","doc":"Alias for `translate/2`","ref":"Idiom.html#t/2"},{"type":"function","title":"Idiom.translate/2","doc":"Translates a key into a target language.\n\nThe `translate/2` function takes two arguments:\n- `key`: The specific key for which the translation is required.\n- `opts`: An optional list of options.","ref":"Idiom.html#translate/2"},{"type":"function","title":"Target and fallback languages - Idiom.translate/2","doc":"For both target and fallback languages, the selected options are based on the following order of priority:\n1. The `:to` and `:fallback` keys in `opts`.\n2. The `:lang` and `:fallback` keys in the current process dictionary.\n3. The application configuration's `:default_lang` and `:default_fallback` keys.\n\nThe language needs to be a single string, whereas the fallback can both be a single string or a list of strings.","ref":"Idiom.html#translate/2-target-and-fallback-languages"},{"type":"function","title":"Namespaces - Idiom.translate/2","doc":"Keys can be namespaced.","ref":"Idiom.html#translate/2-namespaces"},{"type":"function","title":"Configuration - Idiom.translate/2","doc":"Application-wide configuration can be set in `config.exs` like so:\n\n```elixir\nconfig :idiom,\n  default_lang: \"en\",\n  default_fallback: \"fr\"\n  # default_fallback: [\"fr\", \"es\"]\n```","ref":"Idiom.html#translate/2-configuration"},{"type":"function","title":"Examples - Idiom.translate/2","doc":"iex> translate(\"hello\", to: \"es\")\n    \"hola\"\n\n    # If no `:to` option is provided, it will check the process dictionary:\n    iex> Process.put(:lang, \"fr\")\n    iex> translate(\"hello\")\n    \"bonjour\"\n\n    # If neither `:to` option is provided nor `:lang` is set in the process, it will check the application configuration:\n    # Given `config :idiom, default_lang: \"en\"` is set in the `config.exs` file:\n    iex> translate(\"hello\")\n    \"hello\"\n\n    # If a key does not exist in the target language, it will use the `:fallback` option:\n    iex> translate(\"hello\", to: \"de\", fallback: \"fr\")\n    \"bonjour\"\n\n    # If a key does not exist in the target language or the first fallback language:\n    iex> translate(\"hello\", to: \"de\", fallback: [\"pl\", \"fr\"])\n    \"bonjour\"","ref":"Idiom.html#translate/2-examples"},{"type":"type","title":"Idiom.translate_opts/0","doc":"","ref":"Idiom.html#t:translate_opts/0"},{"type":"module","title":"Idiom.Cache","doc":"","ref":"Idiom.Cache.html"},{"type":"function","title":"Idiom.Cache.cache_table_name/0","doc":"","ref":"Idiom.Cache.html#cache_table_name/0"},{"type":"function","title":"Idiom.Cache.get_key/2","doc":"","ref":"Idiom.Cache.html#get_key/2"},{"type":"function","title":"Idiom.Cache.get_translation/4","doc":"","ref":"Idiom.Cache.html#get_translation/4"},{"type":"function","title":"Idiom.Cache.init/2","doc":"","ref":"Idiom.Cache.html#init/2"},{"type":"function","title":"Idiom.Cache.insert_keys/2","doc":"","ref":"Idiom.Cache.html#insert_keys/2"},{"type":"function","title":"Idiom.Cache.map_to_cache_data/4","doc":"","ref":"Idiom.Cache.html#map_to_cache_data/4"},{"type":"function","title":"Idiom.Cache.to_cache_key/3","doc":"","ref":"Idiom.Cache.html#to_cache_key/3"},{"type":"module","title":"Idiom.Languages","doc":"","ref":"Idiom.Languages.html"},{"type":"function","title":"Idiom.Languages.get_language_part_from_code/1","doc":"","ref":"Idiom.Languages.html#get_language_part_from_code/1"},{"type":"function","title":"Idiom.Languages.to_resolve_hierarchy/2","doc":"","ref":"Idiom.Languages.html#to_resolve_hierarchy/2"},{"type":"module","title":"Idiom.Plural","doc":"","ref":"Idiom.Plural.html"},{"type":"function","title":"Idiom.Plural.get_suffix/2","doc":"","ref":"Idiom.Plural.html#get_suffix/2"},{"type":"module","title":"Idiom.PluralPreprocess","doc":"Preprocessor for language-specific pluralization rules.","ref":"Idiom.PluralPreprocess.html"},{"type":"function","title":"Idiom.PluralPreprocess.parse_rules/1","doc":"Parses and sorts language-specific pluralization rules.\n\nThis function takes as input a tuple, where the first element is a string representing the language identifier (e.g., `\"en\"` for English), and the second element is a list of tuples. Each tuple in the list represents a pluralization rule, with the first element being a string that specifies the rule's category (e.g., `\"pluralRule-count-one\"`), and the second element being a string that specifies the rule itself.\n\nThe function parses these rules into abstract syntax trees (ASTs), sorts them according to a predefined order (\"zero\", \"one\", \"two\", \"few\", \"many\", \"other\"), and returns a tuple where the first element is the language identifier and the second element is the AST of a `cond` statement with a clause for each rule and suffix.","ref":"Idiom.PluralPreprocess.html#parse_rules/1"},{"type":"function","title":"Examples - Idiom.PluralPreprocess.parse_rules/1","doc":"```elixir\niex> Idiom.PluralPreprocess.parse_rules({\"en\", [{\"pluralRule-count-one\", \"n = 1\"}]})\n{\"en\", {:cond, [], [[do: [{:->, [], [[{:==, [], [{:n, [], nil}, 1]}], \"one\"]}]]]}}\n```","ref":"Idiom.PluralPreprocess.html#parse_rules/1-examples"},{"type":"module","title":"Idiom.Source.Local","doc":"","ref":"Idiom.Source.Local.html"},{"type":"function","title":"Idiom.Source.Local.data/1","doc":"","ref":"Idiom.Source.Local.html#data/1"},{"type":"module","title":"Idiom.Source.PhraseStrings","doc":"","ref":"Idiom.Source.PhraseStrings.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Source.PhraseStrings.html#child_spec/1"},{"type":"function","title":"Idiom.Source.PhraseStrings.init/1","doc":"","ref":"Idiom.Source.PhraseStrings.html#init/1"},{"type":"function","title":"Idiom.Source.PhraseStrings.start_link/1","doc":"","ref":"Idiom.Source.PhraseStrings.html#start_link/1"},{"type":"module","title":"Idiom.Source.PhraseStrings.OTA","doc":"","ref":"Idiom.Source.PhraseStrings.OTA.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#delete/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#delete!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#get/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#get!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get_strings/1","doc":"","ref":"Idiom.Source.PhraseStrings.OTA.html#get_strings/1"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#head/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#head!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#options/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#options!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#patch/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#patch!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#post/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#post!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#put/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#put!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.request/2","doc":"Perform a request.","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2"},{"type":"function","title":"Options - Idiom.Source.PhraseStrings.OTA.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyworld list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2-options"},{"type":"function","title":"Examples - Idiom.Source.PhraseStrings.OTA.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2-examples"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Idiom.Source.PhraseStrings.OTA.html#request!/2"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#trace/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#trace!/3"},{"type":"type","title":"Idiom.Source.PhraseStrings.OTA.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Idiom.Source.PhraseStrings.OTA.html#t:option/0"},{"type":"module","title":"Idiom.Source.PhraseStrings.Strings","doc":"","ref":"Idiom.Source.PhraseStrings.Strings.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.client/0","doc":"","ref":"Idiom.Source.PhraseStrings.Strings.html#client/0"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#delete/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#delete!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#get/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#get!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#head/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#head!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.list_available_languages/0","doc":"","ref":"Idiom.Source.PhraseStrings.Strings.html#list_available_languages/0"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#options/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#options!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#patch/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#patch!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#post/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#post!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#put/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#put!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.request/2","doc":"Perform a request.","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2"},{"type":"function","title":"Options - Idiom.Source.PhraseStrings.Strings.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyworld list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2-options"},{"type":"function","title":"Examples - Idiom.Source.PhraseStrings.Strings.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2-examples"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Idiom.Source.PhraseStrings.Strings.html#request!/2"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#trace/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#trace!/3"},{"type":"type","title":"Idiom.Source.PhraseStrings.Strings.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Idiom.Source.PhraseStrings.Strings.html#t:option/0"},{"type":"module","title":"Idiom.Supervisor","doc":"","ref":"Idiom.Supervisor.html"},{"type":"function","title":"Idiom.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Supervisor.html#child_spec/1"},{"type":"function","title":"Idiom.Supervisor.start_link/1","doc":"","ref":"Idiom.Supervisor.html#start_link/1"}],"content_type":"text/markdown"}